@@ -1,3 +1,4 @@
+import datetime as dt
 import itertools
 from pydoc import locate
 from typing import Tuple
@@ -15,6 +16,7 @@ from allianceauth.services.hooks import get_extension_logger
 from app_utils.logging import LoggerAddTag
 
 from . import __title__
+from .app_settings import STRUCTURES_HOURS_UNTIL_STALE_NOTIFICATION
 from .constants import EveCategoryId, EveTypeId
 from .helpers.esi_fetch import esi_fetch, esi_fetch_with_localization
 from .providers import esi
@@ -28,36 +30,36 @@ def make_log_prefix(model_manager, id):
 
 
 class EveUniverseManager(models.Manager):
-    def get_or_create_esi(self, eve_id: int) -> tuple:
+    def get_or_create_esi(self, *, id: int) -> tuple:
         """gets or creates eve universe object fetched from ESI if needed.
         Will always get/create parent objects.
 
-        eve_id: Eve Online ID of object
+        id: Eve Online ID of object
 
         Returns: object, created
         """
-        eve_id = int(eve_id)
+        id = int(id)
         try:
-            obj = self.get(id=eve_id)
+            obj = self.get(id=id)
             created = False
         except self.model.DoesNotExist:
-            obj, created = self.update_or_create_esi(eve_id)
+            obj, created = self.update_or_create_esi(id=id)
 
         return obj, created
 
-    def update_or_create_esi(self, eve_id: int) -> tuple:
+    def update_or_create_esi(self, *, id: int) -> tuple:
         """updates or creates Eve Universe object with data fetched from ESI.
         Will always update/create children and get/create parent objects.
 
-        eve_id: Eve Online ID of object
+        id: Eve Online ID of object
 
         Returns: object, created
         """
         from .models import EsiNameLocalization
 
-        eve_id = int(eve_id)
+        id = int(id)
         esi_path = "Universe." + self.model.esi_method()
-        args = {self.model.esi_pk(): eve_id}
+        args = {self.model.esi_pk(): id}
         if self.model.has_esi_localization():
             eve_data_objects = esi_fetch_with_localization(
                 esi_path=esi_path,
@@ -70,7 +72,7 @@ class EveUniverseManager(models.Manager):
                 esi_path=esi_path, args=args
             )  # noqa E123
         defaults = self.model.map_esi_fields_to_model(eve_data_objects)
-        obj, created = self.update_or_create(id=eve_id, defaults=defaults)
+        obj, created = self.update_or_create(id=id, defaults=defaults)
         obj.set_generated_translations()
         obj.save()
         self._update_or_create_children(eve_data_objects)
@@ -82,8 +84,8 @@ class EveUniverseManager(models.Manager):
         for key, child_class in self.model.child_mappings().items():
             ChildClass = locate(__package__ + ".models." + child_class)
             for eve_data_obj_2 in eve_data_obj[key]:
-                eve_id = eve_data_obj_2[ChildClass.esi_pk()]
-                ChildClass.objects.update_or_create_esi(eve_id)
+                id = eve_data_obj_2[ChildClass.esi_pk()]
+                ChildClass.objects.update_or_create_esi(id=id)
 
     def update_all_esi(self) -> int:
         """update all objects from ESI. Returns count of updated  objects"""
@@ -95,7 +97,7 @@ class EveUniverseManager(models.Manager):
         count_updated = 0
         for eve_obj in self.all().order_by("last_updated"):
             try:
-                self.update_or_create_esi(eve_obj.id)
+                self.update_or_create_esi(id=eve_obj.id)
                 count_updated += 1
             except HTTPError:
                 logger.exception("Update interrupted by exception")
@@ -161,40 +163,42 @@ class EveSovereigntyMapManager(models.Manager):
 
 
 class EveEntityManager(models.Manager):
-    def get_or_create_esi(self, eve_entity_id: int) -> tuple:
+    def get_or_create_esi(self, *, id: int) -> tuple:
         """gets or creates EveEntity obj with data fetched from ESI if needed
 
-        eve_id: Eve Online ID of object
+        Args:
+            id: Eve Online ID of object
 
         Returns: object, created
         """
-        eve_entity_id = int(eve_entity_id)
+        id = int(id)
         try:
-            obj = self.get(id=eve_entity_id)
+            obj = self.get(id=id)
             created = False
         except self.model.DoesNotExist:
-            obj, created = self.update_or_create_esi(eve_entity_id)
+            obj, created = self.update_or_create_esi(id=id)
 
         return obj, created
 
-    def update_or_create_esi(self, eve_entity_id: int) -> tuple:
+    def update_or_create_esi(self, *, id: int) -> tuple:
         """updates or creates EveEntity object with data fetched from ESI
 
-        eve_id: Eve Online ID of object
+        Args:
+            id: Eve Online ID of object
 
         Returns: object, created
         """
-        eve_entity_id = int(eve_entity_id)
-        log_prefix = make_log_prefix(self, eve_entity_id)
+        id = int(id)
+        log_prefix = make_log_prefix(self, id)
         response = esi_fetch(
             esi_path="Universe.post_universe_names",
-            args={"ids": [eve_entity_id]},
+            args={"ids": [id]},
         )
         if len(response) > 0:
             first = response[0]
             category = self.model.Category.from_esi_name(first["category"])
             obj, created = self.update_or_create(
-                id=eve_entity_id,
+                id=id,
                 defaults={"category": category, "name": first["name"]},
             )
         else:
@@ -217,11 +221,31 @@ class NotificationBaseQuerySet(models.QuerySet):
         )
 
 
+class NotificationBaseManagerBase(models.Manager):
+    def add_or_remove_timers(self):
+        """Add or remove timers from notifications."""
+        from .models import NotificationType
+
+        cutoff_dt_for_stale = now() - dt.timedelta(
+            hours=STRUCTURES_HOURS_UNTIL_STALE_NOTIFICATION
+        )
+        notifications = (
+            self.filter(notif_type__in=NotificationType.relevant_for_timerboard)
+            .exclude(is_timer_added=True)
+            .filter(timestamp__gte=cutoff_dt_for_stale)
+            .select_related("owner")
+            .order_by("timestamp")
+        )
+        if notifications.exists():
+            for notification in notifications:
+                notification.add_or_remove_timer()
+
+
 class NotificationQuerySet(NotificationBaseQuerySet):
     pass
 
 
-class NotificationManagerBase(models.Manager):
+class NotificationManagerBase(NotificationBaseManagerBase):
     pass
 
 
@@ -232,7 +256,7 @@ class GeneratedNotificationQuerySet(NotificationBaseQuerySet):
     pass
 
 
-class GeneratedNotificationManagerBase(models.Manager):
+class GeneratedNotificationManagerBase(NotificationBaseManagerBase):
     def get_or_create_from_structure(
         self, structure: models.Model, notif_type: models.TextChoices
     ) -> Tuple[models.Model, bool]:
@@ -401,29 +425,30 @@ class StructureQuerySet(models.QuerySet):
 
 
 class StructureManagerBase(models.Manager):
-    def get_or_create_esi(self, structure_id: int, token: Token) -> tuple:
-        """get or create a structure with data from ESI if needed
+    def get_or_create_esi(self, *, id: int, token: Token) -> tuple:
+        """get or create a structure with data from ESI if needed.
 
-        structure_id: Structure ID of object in Eve Online
+        Args:
+            id: Structure ID of object in Eve Online
+            token: ``esi.models.Token`` object with scope:
+                ``esi-universe.read_structures.v1``
 
-        token: ``esi.models.Token`` object with scope:
-        ``esi-universe.read_structures.v1``
-
-        Returns: object, created
+        Returns:
+            object, created
         """
+        id = int(id)
         try:
-            obj = self.get(id=structure_id)
+            obj = self.get(id=id)
             return obj, False
         except self.model.DoesNotExist:
-            return self.update_or_create_esi(structure_id, token)
+            return self.update_or_create_esi(id=id, token=token)
 
-    def update_or_create_esi(self, structure_id: int, token: Token) -> tuple:
+    def update_or_create_esi(self, *, id: int, token: Token) -> tuple:
         """update or create a structure from ESI for given structure ID
         This will only fetch basic info about a structure
 
         Args:
-            structure_id: Structure ID of object in Eve Online
-
+            id: Structure ID of object in Eve Online
             token: ``esi.models.Token`` object with scope: ``esi-universe.read_structures.v1``
 
         Returns:
@@ -431,15 +456,16 @@ class StructureManagerBase(models.Manager):
         """
         from .models import Owner
 
-        logger.info("Trying to fetch structure from ESI with ID %s", structure_id)
+        id = int(id)
+        logger.info("Trying to fetch structure from ESI with ID %s", id)
         if token is None:
             raise ValueError("Can not fetch structure without token")
 
         structure_info = esi.client.Universe.get_universe_structures_structure_id(
-            structure_id=structure_id, token=token.valid_access_token()
+            structure_id=id, token=token.valid_access_token()
         ).results()
         structure = {
-            "structure_id": structure_id,
+            "structure_id": id,
             "name": self.model.extract_name_from_esi_response(structure_info["name"]),
             "position": structure_info["position"],
             "type_id": structure_info["type_id"],
@@ -464,9 +490,9 @@ class StructureManagerBase(models.Manager):
         )
         from .models.eveuniverse import EveUniverse
 
-        eve_type, _ = EveType.objects.get_or_create_esi(structure["type_id"])
+        eve_type, _ = EveType.objects.get_or_create_esi(id=structure["type_id"])
         eve_solar_system, _ = EveSolarSystem.objects.get_or_create_esi(
-            structure["system_id"]
+            id=structure["system_id"]
         )
         fuel_expires_at = (
             structure["fuel_expires"] if "fuel_expires" in structure else None
@@ -502,11 +528,13 @@ class StructureManagerBase(models.Manager):
         position_y = structure["position"]["y"] if "position" in structure else None
         position_z = structure["position"]["z"] if "position" in structure else None
         if "planet_id" in structure:
-            eve_planet, _ = EvePlanet.objects.get_or_create_esi(structure["planet_id"])
+            eve_planet, _ = EvePlanet.objects.get_or_create_esi(
+                id=structure["planet_id"]
+            )
         else:
             eve_planet = None
         if "moon_id" in structure:
-            eve_moon, _ = EveMoon.objects.get_or_create_esi(structure["moon_id"])
+            eve_moon, _ = EveMoon.objects.get_or_create_esi(id=structure["moon_id"])
         else:
             eve_moon = None
         try:
