@@ -18,10 +18,8 @@ from django.utils.functional import classproperty
 from django.utils.timezone import now
 from django.utils.translation import gettext
 from django.utils.translation import gettext_lazy as _
-from esi.models import Token
 from eveuniverse.models import EveEntity as EveEntity2
 
-from allianceauth.eveonline.evelinks import dotlan, eveimageserver
 from allianceauth.services.hooks import get_extension_logger
 from app_utils.datetime import (
     DATETIME_FORMAT,
@@ -34,6 +32,7 @@ from app_utils.urls import static_file_absolute_url
 
 from .. import __title__
 from ..app_settings import (  # STRUCTURES_NOTIFICATION_DISABLE_ESI_FUEL_ALERTS,
+    STRUCTURES_ADD_TIMERS,
     STRUCTURES_DEFAULT_LANGUAGE,
     STRUCTURES_FEATURE_REFUELED_NOTIFICATIONS,
     STRUCTURES_MOON_EXTRACTION_TIMERS_ENABLED,
@@ -43,14 +42,9 @@ from ..app_settings import (  # STRUCTURES_NOTIFICATION_DISABLE_ESI_FUEL_ALERTS,
 )
 from ..constants import EveCategoryId, EveCorporationId, EveTypeId
 from ..core import starbases
-from ..managers import (
-    EveEntityManager,
-    GeneratedNotificationManager,
-    NotificationManager,
-    WebhookManager,
-)
+from ..managers import GeneratedNotificationManager, NotificationManager, WebhookManager
 from ..webhooks.models import WebhookBase
-from .eveuniverse import EveMoon, EvePlanet, EveSolarSystem
+from .eveuniverse import EveEntity, EveMoon, EvePlanet, EveSolarSystem
 from .structures import Structure
 
 if "timerboard" in app_labels():
@@ -408,63 +402,6 @@ class Webhook(WebhookBase):
         return f"**{text}**" if text else ""
 
 
-class EveEntity(models.Model):
-    """An EVE entity like a character or an alliance."""
-
-    class Category(models.IntegerChoices):
-        CHARACTER = 1, "character"
-        CORPORATION = 2, "corporation"
-        ALLIANCE = 3, "alliance"
-        FACTION = 4, "faction"
-        OTHER = 5, "other"
-
-        @classmethod
-        def from_esi_name(cls, esi_name: str) -> "EveEntity.Category":
-            """Returns category for given ESI name."""
-            for choice in cls.choices:
-                if esi_name == choice[1]:
-                    return cls(choice[0])
-            return cls.OTHER
-
-    id = models.PositiveIntegerField(primary_key=True, help_text="Eve Online ID")
-    category = models.IntegerField(choices=Category.choices)
-    name = models.CharField(max_length=255, null=True, default=None, blank=True)
-
-    objects = EveEntityManager()
-
-    def __str__(self) -> str:
-        return str(self.name)
-
-    def __repr__(self) -> str:
-        return "{}(id={}, category='{}', name='{}')".format(
-            self.__class__.__name__, self.id, self.get_category_display(), self.name
-        )
-
-    @property
-    def profile_url(self) -> str:
-        """Returns link to website with profile info about this entity."""
-        if self.category == self.Category.CORPORATION:
-            url = dotlan.corporation_url(self.name)
-        elif self.category == self.Category.ALLIANCE:
-            url = dotlan.alliance_url(self.name)
-        else:
-            url = ""
-        return url
-
-    def icon_url(self, size: int = 32) -> str:
-        if self.category == self.Category.ALLIANCE:
-            return eveimageserver.alliance_logo_url(self.id, size)
-        elif (
-            self.category == self.Category.CORPORATION
-            or self.category == self.Category.FACTION
-        ):
-            return eveimageserver.corporation_logo_url(self.id, size)
-        elif self.category == self.Category.CHARACTER:
-            return eveimageserver.character_portrait_url(self.id, size)
-        else:
-            raise NotImplementedError()
-
-
 class NotificationBase(models.Model):
     """Base model for a notification."""
 
@@ -731,75 +668,72 @@ class NotificationBase(models.Model):
 
         return username, avatar_url
 
-    def process_for_timerboard(self, token: Token = None) -> bool:
-        """Add/removes a timer related to this notification for some types
+    def add_or_remove_timer(self) -> bool:
+        """Add/remove a timer related to this notification for some types.
 
-        Returns True when a timer was processed, else False
+        Returns True when timers where added or removed, else False
         """
-        timer_created = False
+        if not STRUCTURES_ADD_TIMERS:
+            return False
+
         if (
-            has_auth_timers or has_structure_timers
-        ) and self.notif_type in NotificationType.relevant_for_timerboard:
-            parsed_text = self.parsed_text()
-            try:
-                with translation.override(STRUCTURES_DEFAULT_LANGUAGE):
-                    if self.notif_type in [
-                        NotificationType.STRUCTURE_LOST_ARMOR,
-                        NotificationType.STRUCTURE_LOST_SHIELD,
-                    ]:
-                        timer_created = self._gen_timer_structure_reinforcement(
-                            parsed_text, token
-                        )
-                    elif self.notif_type == NotificationType.SOV_STRUCTURE_REINFORCED:
-                        timer_created = self._gen_timer_sov_reinforcements(parsed_text)
-                    elif self.notif_type == NotificationType.ORBITAL_REINFORCED:
-                        timer_created = self._gen_timer_orbital_reinforcements(
-                            parsed_text
-                        )
-                    elif self.notif_type in [
-                        NotificationType.MOONMINING_EXTRACTION_STARTED,
-                        NotificationType.MOONMINING_EXTRACTION_CANCELLED,
-                    ]:
-                        if not STRUCTURES_MOON_EXTRACTION_TIMERS_ENABLED:
-                            timer_created = None
-                        else:
-                            timer_created = self._gen_timer_moon_extraction(parsed_text)
-                    elif self.notif_type == NotificationType.TOWER_REINFORCED_EXTRA:
-                        timer_created = self._gen_timer_tower_reinforcements(
-                            parsed_text
-                        )
-                    else:
-                        raise NotImplementedError()
+            not has_auth_timers and not has_structure_timers
+        ) or self.notif_type not in NotificationType.relevant_for_timerboard:
+            return False
 
-                if timer_created:
-                    logger.info(
-                        "{}: added timer_created related notification".format(
-                            self.notification_id
-                        )
+        parsed_text = self.parsed_text()
+        try:
+            with translation.override(STRUCTURES_DEFAULT_LANGUAGE):
+                if self.notif_type in [
+                    NotificationType.STRUCTURE_LOST_ARMOR,
+                    NotificationType.STRUCTURE_LOST_SHIELD,
+                ]:
+                    timer_processed = self._gen_timer_structure_reinforcement(
+                        parsed_text
                     )
+                elif self.notif_type == NotificationType.SOV_STRUCTURE_REINFORCED:
+                    timer_processed = self._gen_timer_sov_reinforcements(parsed_text)
+                elif self.notif_type == NotificationType.ORBITAL_REINFORCED:
+                    timer_processed = self._gen_timer_orbital_reinforcements(
+                        parsed_text
+                    )
+                elif self.notif_type in [
+                    NotificationType.MOONMINING_EXTRACTION_STARTED,
+                    NotificationType.MOONMINING_EXTRACTION_CANCELLED,
+                ]:
+                    if not STRUCTURES_MOON_EXTRACTION_TIMERS_ENABLED:
+                        timer_processed = None
+                    else:
+                        timer_processed = self._gen_timer_moon_extraction(parsed_text)
+                elif self.notif_type == NotificationType.TOWER_REINFORCED_EXTRA:
+                    timer_processed = self._gen_timer_tower_reinforcements(parsed_text)
+                else:
+                    raise NotImplementedError()
 
-                self.is_timer_added = timer_created
-                self.save()
+            if timer_processed:
+                logger.info("%s: Created timer for notification", self.notification_id)
 
-            except OSError as ex:
-                logger.warning(
-                    "%s: Failed to add timer from notification: %s",
-                    self,
-                    ex,
-                    exc_info=True,
-                )
+            self.is_timer_added = timer_processed
+            self.save()
 
-        return timer_created
+        except OSError as ex:
+            logger.warning(
+                "%s: Failed to add timer from notification: %s",
+                self,
+                ex,
+                exc_info=True,
+            )
 
-    def _gen_timer_structure_reinforcement(
-        self, parsed_text: str, token: Token
-    ) -> bool:
+        return timer_processed
+
+    def _gen_timer_structure_reinforcement(self, parsed_text: str) -> bool:
         """Generate timer for structure reinforcements"""
+        token = self.owner.fetch_token()
         structure_obj, _ = Structure.objects.get_or_create_esi(
-            parsed_text["structureID"], token
+            id=parsed_text["structureID"], token=token
         )
         eve_time = self.timestamp + ldap_timedelta_2_timedelta(parsed_text["timeLeft"])
-        timer_added = False
+        timer_processed = False
         if has_auth_timers:
             details_map = {
                 NotificationType.STRUCTURE_LOST_SHIELD: gettext("Armor timer"),
@@ -815,7 +749,7 @@ class NotificationBase(models.Model):
                 eve_corp=self.owner.corporation,
                 corp_timer=STRUCTURES_TIMERS_ARE_CORP_RESTRICTED,
             )
-            timer_added = True
+            timer_processed = True
 
         if has_structure_timers:
             timer_map = {
@@ -846,9 +780,9 @@ class NotificationBase(models.Model):
                 owner_name=self.owner.corporation.corporation_name,
                 details_notes=self._timer_details_notes(),
             )
-            timer_added = True
+            timer_processed = True
 
-        return timer_added
+        return timer_processed
 
     def _gen_timer_sov_reinforcements(self, parsed_text: str) -> bool:
         """Generate timer for sov reinforcements."""
@@ -856,7 +790,7 @@ class NotificationBase(models.Model):
             return False
 
         solar_system, _ = EveSolarSystem.objects.get_or_create_esi(
-            parsed_text["solarSystemID"]
+            id=parsed_text["solarSystemID"]
         )
         event_type = parsed_text["campaignEventType"]
         if event_type in self.MAP_CAMPAIGN_EVENT_2_TYPE_ID:
@@ -867,7 +801,7 @@ class NotificationBase(models.Model):
             structure_type_name = "Other"
 
         eve_time = ldap_time_2_datetime(parsed_text["decloakTime"])
-        timer_added = False
+        timer_processed = False
         if has_auth_timers:
             AuthTimer.objects.create(
                 details=gettext("Sov timer"),
@@ -879,7 +813,7 @@ class NotificationBase(models.Model):
                 eve_corp=self.owner.corporation,
                 corp_timer=STRUCTURES_TIMERS_ARE_CORP_RESTRICTED,
             )
-            timer_added = True
+            timer_processed = True
 
         if has_structure_timers:
             eve_solar_system, _ = EveSolarSystem2.objects.get_or_create_esi(
@@ -905,18 +839,18 @@ class NotificationBase(models.Model):
                 owner_name=self.sender.name,
                 details_notes=self._timer_details_notes(),
             )
-            timer_added = True
+            timer_processed = True
 
-        return timer_added
+        return timer_processed
 
     def _gen_timer_orbital_reinforcements(self, parsed_text: str) -> bool:
         """Generate timer for orbital reinforcements."""
         solar_system, _ = EveSolarSystem.objects.get_or_create_esi(
-            parsed_text["solarSystemID"]
+            id=parsed_text["solarSystemID"]
         )
-        planet, _ = EvePlanet.objects.get_or_create_esi(parsed_text["planetID"])
+        planet, _ = EvePlanet.objects.get_or_create_esi(id=parsed_text["planetID"])
         eve_time = ldap_time_2_datetime(parsed_text["reinforceExitTime"])
-        timer_added = False
+        timer_processed = False
         if has_auth_timers:
             AuthTimer.objects.create(
                 details=gettext("Final timer"),
@@ -928,7 +862,7 @@ class NotificationBase(models.Model):
                 eve_corp=self.owner.corporation,
                 corp_timer=STRUCTURES_TIMERS_ARE_CORP_RESTRICTED,
             )
-            timer_added = True
+            timer_processed = True
 
         if has_structure_timers:
             eve_solar_system, _ = EveSolarSystem2.objects.get_or_create_esi(
@@ -956,16 +890,16 @@ class NotificationBase(models.Model):
                 owner_name=self.owner.corporation.corporation_name,
                 details_notes=self._timer_details_notes(),
             )
-            timer_added = True
+            timer_processed = True
 
-        return timer_added
+        return timer_processed
 
     def _gen_timer_moon_extraction(self, parsed_text: str) -> bool:
         """Generate timer for moon mining extractions."""
         solar_system, _ = EveSolarSystem.objects.get_or_create_esi(
-            parsed_text["solarSystemID"]
+            id=parsed_text["solarSystemID"]
         )
-        moon, _ = EveMoon.objects.get_or_create_esi(parsed_text["moonID"])
+        moon, _ = EveMoon.objects.get_or_create_esi(id=parsed_text["moonID"])
         if "readyTime" in parsed_text:
             eve_time = ldap_time_2_datetime(parsed_text["readyTime"])
         else:
@@ -975,7 +909,7 @@ class NotificationBase(models.Model):
         planet_moon = moon.name
         structure_type_name = "Moon Mining Cycle"
         objective = "Friendly"
-        timer_added = False
+        timer_processed = False
 
         if has_structure_timers:
             eve_solar_system, _ = EveSolarSystem2.objects.get_or_create_esi(
@@ -1006,7 +940,7 @@ class NotificationBase(models.Model):
                     eve_corp=self.owner.corporation,
                     corp_timer=STRUCTURES_TIMERS_ARE_CORP_RESTRICTED,
                 )
-                timer_added = True
+                timer_processed = True
 
             if has_structure_timers:
                 eve_solar_system, _ = EveSolarSystem2.objects.get_or_create_esi(
@@ -1034,16 +968,16 @@ class NotificationBase(models.Model):
                     owner_name=self.owner.corporation.corporation_name,
                     details_notes=self._timer_details_notes(),
                 )
-                timer_added = True
+                timer_processed = True
 
         elif self.notif_type == NotificationType.MOONMINING_EXTRACTION_CANCELLED:
+            timer_processed = True
             notifications_qs = Notification.objects.filter(
                 notif_type=NotificationType.MOONMINING_EXTRACTION_STARTED,
                 owner=self.owner,
                 is_timer_added=True,
                 timestamp__lte=self.timestamp,
             ).order_by("-timestamp")
-
             for notification in notifications_qs:
                 parsed_text_2 = notification.parsed_text()
                 my_structure_type_id = parsed_text_2["structureTypeID"]
@@ -1083,13 +1017,13 @@ class NotificationBase(models.Model):
                             "obsolete structure timers related to notification"
                         )
 
-        return timer_added
+        return timer_processed
 
     def _gen_timer_tower_reinforcements(self, parsed_text: str) -> bool:
         """Generate timer for tower reinforcements."""
         structure = self.structures.first()
         eve_time = dt.datetime.fromisoformat(self.details["reinforced_until"])
-        timer_added = False
+        timer_processed = False
         if has_auth_timers:
             structure_type_map = {
                 starbases.StarbaseSize.SMALL: "POS[S]",
@@ -1109,7 +1043,7 @@ class NotificationBase(models.Model):
                 eve_corp=self.owner.corporation,
                 corp_timer=STRUCTURES_TIMERS_ARE_CORP_RESTRICTED,
             )
-            timer_added = True
+            timer_processed = True
 
         if has_structure_timers:
             eve_solar_system, _ = EveSolarSystem2.objects.get_or_create_esi(
@@ -1137,9 +1071,9 @@ class NotificationBase(models.Model):
                 owner_name=self.owner.corporation.corporation_name,
                 details_notes=self._timer_details_notes(),
             )
-            timer_added = True
+            timer_processed = True
 
-        return timer_added
+        return timer_processed
 
     def _timer_details_notes(self) -> str:
         """Return generated details notes string for Timers."""
@@ -1286,9 +1220,7 @@ class Notification(NotificationBase):
                 raise ValueError("text property not provided and can not be generated.")
             kwargs["text"] = yaml.dump(data)
         if "sender" not in kwargs:
-            sender, _ = EveEntity.objects.get_or_create_esi(
-                eve_entity_id=EveCorporationId.DED
-            )
+            sender, _ = EveEntity.objects.get_or_create_esi(id=EveCorporationId.DED)
             kwargs["sender"] = sender
         kwargs["notification_id"] = cls.TEMPORARY_NOTIFICATION_ID
         kwargs["owner"] = structure.owner
