@@ -29,7 +29,6 @@ from app_utils.logging import LoggerAddTag
 
 from .. import __title__
 from ..app_settings import (
-    STRUCTURES_ADD_TIMERS,
     STRUCTURES_ADMIN_NOTIFICATIONS_ENABLED,
     STRUCTURES_DEFAULT_LANGUAGE,
     STRUCTURES_DEVELOPER_MODE,
@@ -677,7 +676,7 @@ class Owner(models.Model):
                 # making sure we have all solar systems loaded
                 # incl. their planets for later name matching
                 for solar_system_id in {int(x["system_id"]) for x in pocos}:
-                    EveSolarSystem.objects.get_or_create_esi(solar_system_id)
+                    EveSolarSystem.objects.get_or_create_esi(id=solar_system_id)
 
                 # compile pocos into structures list
                 for office_id, poco in pocos_2.items():
@@ -968,12 +967,18 @@ class Owner(models.Model):
             )
             detail.fuels.all().delete()
             for fuel in data["fuels"]:
-                eve_type, _ = EveType.objects.get_or_create_esi(fuel["type_id"])
+                # TODO: Move outside of transaction
+                eve_type, _ = EveType.objects.get_or_create_esi(id=fuel["type_id"])
                 StarbaseDetailFuel.objects.create(
                     eve_type=eve_type, detail=detail, quantity=fuel["quantity"]
                 )
         return detail
 
+    def add_or_remove_timers_from_notifications(self):
+        """Add/remove timers from esi and generated notification of this owner."""
+        self.notification_set.add_or_remove_timers()
+        self.generatednotification_set.add_or_remove_timers()
+
     def fetch_notifications_esi(self, user: User = None) -> None:
         """Fetch notifications for this owner from ESI and process them."""
         notifications_count_all = 0
@@ -989,7 +994,6 @@ class Owner(models.Model):
                 self,
                 notifications_count_new,
             )
-            self._process_timers_for_notifications(token)
             notifications_count_all += notifications_count_new
         else:
             logger.info("%s: No new notifications received from ESI", self)
@@ -1057,7 +1061,7 @@ class Owner(models.Model):
             sender_type = EveEntity.Category.from_esi_name(notification["sender_type"])
             if sender_type != EveEntity.Category.OTHER:
                 sender, _ = EveEntity.objects.get_or_create_esi(
-                    eve_entity_id=notification["sender_id"]
+                    id=notification["sender_id"]
                 )
             else:
                 sender, _ = EveEntity.objects.get_or_create(
@@ -1082,28 +1086,6 @@ class Owner(models.Model):
             )
         return len(new_notifications)
 
-    # TODO: run this as separate task
-    def _process_timers_for_notifications(self, token: Token):
-        """processes notifications for timers if any"""
-        if STRUCTURES_ADD_TIMERS:
-            cutoff_dt_for_stale = now() - dt.timedelta(
-                hours=STRUCTURES_HOURS_UNTIL_STALE_NOTIFICATION
-            )
-            notifications = (
-                self.notification_set.filter(
-                    notif_type__in=NotificationType.relevant_for_timerboard
-                )
-                .exclude(is_timer_added=True)
-                .filter(timestamp__gte=cutoff_dt_for_stale)
-                .select_related("owner", "sender")
-                .order_by("timestamp")
-            )
-            if notifications.exists():
-                if not token:
-                    token = self.fetch_token()
-                for notification in notifications:
-                    notification.process_for_timerboard(token)
-
     def _process_moon_notifications(self):
         """processes notifications for timers if any"""
         empty_refineries = Structure.objects.filter(
@@ -1134,7 +1116,7 @@ class Owner(models.Model):
                 if refinery.id in structure_id_2_moon_id:
                     logger.info("%s: Updating moon for structure %s", self, refinery)
                     eve_moon, _ = EveMoon.objects.get_or_create_esi(
-                        eve_id=structure_id_2_moon_id[refinery.id]
+                        id=structure_id_2_moon_id[refinery.id]
                     )
                     refinery.eve_moon = eve_moon
                     refinery.save()
